import { PropsWithChildren, FC, ReactNode } from 'react';
import { QueryClientProviderProps } from '@tanstack/react-query';
import { WagmiProviderProps } from 'wagmi';

type UnifyIntersection<T> = {
    [K in keyof T]: T[K];
} & unknown;

interface ReactQueryBaseProps extends QueryClientProviderProps {
}
interface ReactQueryEnabledProps extends ReactQueryBaseProps {
    enabled: true;
}
interface ReactQueryDisabledProps extends Partial<ReactQueryBaseProps> {
    enabled: false;
}
type ReactQueryProps = PropsWithChildren<ReactQueryEnabledProps | ReactQueryDisabledProps>;

type WagmiBaseProps = Omit<WagmiProviderProps, "children">;
interface WagmiEnabledProps extends WagmiBaseProps {
    enabled: true;
}
interface WagmiDisabledProps {
    enabled: false;
}
type WagmiProps = PropsWithChildren<WagmiEnabledProps | WagmiDisabledProps>;

declare const SettleMintProvider: FC<{
    children: ReactNode;
    wagmi: WagmiProps;
    reactQuery: ReactQueryProps;
}>;

export { SettleMintProvider, type UnifyIntersection };
